\name{att}
\alias{att}
\title{Example of ATT estimation from CEM output}
\description{
An example of ATT estimation from CEM output
}
\usage{
att(obj, formula, data, model="lm", family="binomial", bayes=FALSE,  Rep=100)
}
\arguments{
  \item{obj}{a \code{cem.match} or \code{multicem} object}
  \item{data}{a single data.frame or a list of data.frame's in case of \code{multicem}}
  \item{formula}{formula type specification of model. See Details.}
  \item{model}{either \code{lm} or \code{glm}. See Details.}
  \item{family}{used if model is \code{glm}, otherwise ignored.}
  \item{bayes}{run Bayesian hierarchical model. Default = \code{FALSE}.}
  \item{Rep}{number of MCMC iteration when estimating the Bayes model. Default = 100.}
}
\details{

Argument \code{model} can be \code{lm} or \code{glm}, depending on the
nature of the outcome variable.  If the outcome is \code{y} and the
treatment variable is \code{T}, then a \code{formula} like \code{y ~ T}
will produce the simplest estimate the ATT: with lm, it is just the
coefficient on \code{T}, which is the same as the difference in means,
weighted by CEM stratum size.  Users can add covariates to span any
remaining imbalance after the match, such as \code{y ~ T + age + sex},
to adjust for variables \code{age} and \code{sex}.

In the case of multiply imputed datasets, the model is applied to each
single matched data and the ATT and is the standard error estimated
using the standard formulas for combining results of multiply imputed
data.  

When \code{bayes} = \code{TRUE}, a Bayesian hierarchical model is
estimated to account for potentially heterogeneous treatment effects
among CEM strata.  In this case, the function also returns a mixed model
approach as a weighted average of ATT estimate on the CEM-matched strata
and a Bayes hierarchical model on the CEM-unmatched strata.

In both the Hierarchical Bayes and mixed Bayes model, the complete set
of treated units is involved in the estimation and so the estimand
remains fixed to the sample average treatment effect on the treated.
The prior used for the treatment effect is calculated empirically from
the CEM-matched units. }
\value{
  A matrix of estimates with their standard error, or a list in
  the case of \code{multicem}.  } 
\references{Stefano Iacus, Gary King, Giuseppe Porro, ``Matching for
  Casual Inference Without Balance Checking,''
  http://gking.harvard.edu/files/abs/cem-abs.shtml}
\author{Stefano Iacus, Gary King, and Giuseppe Porro}

\examples{ 
data(LL)

# cem match: automatic bin choice
mat <- cem(treatment="treated",data=LL, drop="re78")
mat
mat$k2k

# ATT estimate
att(mat, re78~treated,  data=LL)


# reduce the match into k2k using euclidean distance within cem strata
mat2 <- k2k(mat, LL, "euclidean", 1)
mat2
mat2$k2k

# ATT estimate after k2k
att(mat2, re78~treated, data=LL)

# example with missing data
# using multiply imputated data
# we use Amelia for multiple imputation
if(require(Amelia)){
 data(LL)
 n <- dim(LL)[1]
 k <- dim(LL)[2]

# we generate missing values in 30% of the rows of LL data
# randomly in one colum per row
 LL1 <- LL
 idx <- sample(1:n, .3*n)
 invisible(sapply(idx, function(x) LL1[x,sample(2:k,1)] <<- NA))


 imputed <- amelia(LL1)[1:5] 

 mat <- cem("treated", datalist=imputed, data=LL1, drop="re78")

 print(mat)
  
 att(mat, re78 ~ treated, data=imputed)
}
}
\keyword{multivariate}

